==> genometools-1.0.5.tar.gz: genometools-1.0.5/src/libgtcore/scorefunction.h <==
/*
  Copyright (c) 2006-2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006-2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef SCOREFUNCTION_H
#define SCOREFUNCTION_H

#include "libgtcore/scorematrix.h"

typedef struct ScoreFunction ScoreFunction;

ScoreFunction* scorefunction_new(ScoreMatrix*, /* takes ownership  */
                                 int deletion_score, int insertion_score,
                                 Env*);
int            scorefunction_get_score(const ScoreFunction*,
                                       unsigned int, unsigned int);
int            scorefunction_get_deletion_score(const ScoreFunction*);
int            scorefunction_get_insertion_score(const ScoreFunction*);
void           scorefunction_delete(ScoreFunction*, Env*);

#endif

==> genometools-1.1.1.tar.gz: genometools-1.1.1/src/libgtcore/scorefunction.h <==
/*
  Copyright (c) 2006-2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef SCOREFUNCTION_H
#define SCOREFUNCTION_H

#include "libgtcore/score_matrix.h"

typedef struct ScoreFunction ScoreFunction;

ScoreFunction* scorefunction_new(ScoreMatrix*, /* takes ownership  */
                                 int deletion_score, int insertion_score);
int            scorefunction_get_score(const ScoreFunction*,
                                       unsigned int, unsigned int);
const int**    scorefunction_get_scores(const ScoreFunction*);
int            scorefunction_get_deletion_score(const ScoreFunction*);
int            scorefunction_get_insertion_score(const ScoreFunction*);
void           scorefunction_delete(ScoreFunction*);

#endif
